==> mcu_plus_sdk_am64x_08_00_00_21_docs_only.tar.xz: mcu_plus_sdk_am64x_08_00_00_21_docs_only/docs/industrial_protocol_docs/am64x/iolink_master/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "IO-Link Master", "index.html", [
    [ "Introduction", "index.html", null ],
    [ "Release Notes", "releasenotes.html", [
      [ "Overview", "releasenotes.html#releasenotesoverview", null ],
      [ "Licensing", "releasenotes.html#releasenoteslicensing", null ],
      [ "Release Version 1.03.03", "releasenotes.html#version_release10303", null ],
      [ "Release Version 1.03.02", "releasenotes.html#version_release10302", null ],
      [ "Release Version 1.03.01", "releasenotes.html#version_release10301", null ],
      [ "Release Version 1.03.00", "releasenotes.html#version_release10300", null ],
      [ "Release Version 1.02.02", "releasenotes.html#version_release10202", null ],
      [ "Release Version 1.02.01", "releasenotes.html#version_release10201", null ],
      [ "Release Version 1.01.01", "releasenotes.html#version_release10101", null ],
      [ "Release Version 1.01.00", "releasenotes.html#version_release10100", null ]
    ] ],
    [ "General Information", "generalinformation.html", [
      [ "Disclaimer", "disclaimer.html", null ],
      [ "Target Audience", "targetaudience.html", null ],
      [ "Delivery Content", "deliverycontent.html", null ],
      [ "Supported Functionality", "functionality.html", null ],
      [ "Customer Service", "customerservice.html", null ],
      [ "Abbreviations", "abbreviations.html", null ],
      [ "References", "references.html", null ]
    ] ],
    [ "IO-Link Master Example Project", "usergroup0.html", [
      [ "CCS Example Project", "page_quickstart.html#page_example_am64x", null ],
      [ "SMI - Graphical User Interface", "page_quickstart.html#page_gui_am64x", null ]
    ] ],
    [ "SMI", "page_smi.html", [
      [ "Architecture", "page_smi.html#sect_smi_arch", null ],
      [ "Initialization and Run", "page_smi.html#sect_smi_init", null ],
      [ "Services", "page_smi.html#sect_smi_services", null ],
      [ "Callbacks", "page_smi.html#sect_smi_callbacks", null ],
      [ "ArgBlocks", "page_smi.html#sect_smi_argblock", null ],
      [ "Direct Services", "page_smi.html#sect_smi_directservice", null ]
    ] ],
    [ "API without SMI", "page_api.html", [
      [ "General API", "page_api.html#section_api_general", null ],
      [ "Timing API", "page_api.html#section_api_Timing", null ],
      [ "Physical Layer API", "page_api.html#section_pl_api_functions", [
        [ "Port Configuration", "page_api.html#section_api_configuration", null ]
      ] ],
      [ "Process Data API", "page_api.html#section_pd_api_functions", null ],
      [ "ISDU/Parameter API", "page_api.html#section_isdu_api_functions", null ],
      [ "Event API", "page_api.html#section_evt_api_functions", null ],
      [ "Data Storage API", "page_api.html#section_ds_api_functions", null ]
    ] ],
    [ "Implementation", "_implementation.html", [
      [ "Hardware Port", "page_hwport.html", null ],
      [ "Device Communication", "page_startcom.html", null ],
      [ "Data Storage", "page_datastorage.html", null ]
    ] ],
    [ "API Reference", "modules.html", "modules" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Related Information", "usergroup1.html", [
      [ "IO-Link Specification v1.1.2", "^http://www.io-link.com/share/Downloads/Spec-Interface/IOL-Interface-Spec_10002_V112_Jul13.pdf", null ],
      [ "IO-Link Test Specification v1.1.2", "^http://www.io-link.com/share/Downloads/Testspec/IOL-Test-Spec_10032_V112_Jul14.pdf", null ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"_implementation.html",
"group__group__iol__types.html#ggaabedc17180f6c9346ae9c8d39cc79088ab283a385ff52fa37a94dfa0d1ee6e404",
"releasenotes.html#version_release10201",
"struct_i_o_l_m___s_m_i___s_p_d_in_out.html#acb17d54cb26be2232a3bb2d13894e0dd"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> mcu_plus_sdk_am64x_08_01_00_36_docs_only.tar.xz: mcu_plus_sdk_am64x_08_01_00_36_docs_only/docs/industrial_protocol_docs/am64x/iolink_master/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "IO-Link Master", "index.html", [
    [ "Introduction", "index.html", null ],
    [ "Datasheet", "datasheet.html", null ],
    [ "Release Notes", "releasenotes.html", [
      [ "Known Issues", "known_issues.html", null ],
      [ "Overview", "releasenotes.html#releasenotesoverview", null ],
      [ "Licensing", "releasenotes.html#releasenoteslicensing", null ],
      [ "Release Version 1.05.01", "releasenotes.html#version_release10501", null ],
      [ "Release Version 1.05.00", "releasenotes.html#version_release10500", null ],
      [ "Release Version 1.04.06", "releasenotes.html#version_release10406", null ],
      [ "Release Version 1.04.05", "releasenotes.html#version_release10405", null ],
      [ "Release Version 1.04.04", "releasenotes.html#version_release10404", null ],
      [ "Release Version 1.04.03", "releasenotes.html#version_release10403", null ],
      [ "Release Version 1.04.02", "releasenotes.html#version_release10402", null ],
      [ "Release Version 1.04.01", "releasenotes.html#version_release10401", null ],
      [ "Release Version 1.04.00", "releasenotes.html#version_release10400", null ],
      [ "Release Version 1.03.03", "releasenotes.html#version_release10303", null ],
      [ "Release Version 1.03.02", "releasenotes.html#version_release10302", null ],
      [ "Release Version 1.03.01", "releasenotes.html#version_release10301", null ],
      [ "Release Version 1.03.00", "releasenotes.html#version_release10300", null ],
      [ "Release Version 1.02.02", "releasenotes.html#version_release10202", null ],
      [ "Release Version 1.02.01", "releasenotes.html#version_release10201", null ],
      [ "Release Version 1.01.01", "releasenotes.html#version_release10101", null ],
      [ "Release Version 1.01.00", "releasenotes.html#version_release10100", null ]
    ] ],
    [ "General Information", "generalinformation.html", [
      [ "Disclaimer", "disclaimer.html", null ],
      [ "Target Audience", "targetaudience.html", null ],
      [ "Delivery Content", "deliverycontent.html", null ],
      [ "Datasheet", "datasheet.html", null ],
      [ "Customer Service", "customerservice.html", null ],
      [ "Abbreviations", "abbreviations.html", null ],
      [ "References", "references.html", null ]
    ] ],
    [ "IO-Link Master Example Project", "usergroup0.html", [
      [ "CCS Example Project", "page_quickstart.html#page_example_am64x", null ]
    ] ],
    [ "SMI", "page_smi.html", [
      [ "Architecture", "page_smi.html#sect_smi_arch", null ],
      [ "Initialization and Run", "page_smi.html#sect_smi_init", null ],
      [ "Services", "page_smi.html#sect_smi_services", null ],
      [ "Callbacks", "page_smi.html#sect_smi_callbacks", null ],
      [ "ArgBlocks", "page_smi.html#sect_smi_argblock", null ],
      [ "Direct Services", "page_smi.html#sect_smi_directservice", null ]
    ] ],
    [ "API without SMI", "page_api.html", [
      [ "General API", "page_api.html#section_api_general", null ],
      [ "Timing API", "page_api.html#section_api_Timing", null ],
      [ "Physical Layer API", "page_api.html#section_pl_api_functions", [
        [ "Port Configuration", "page_api.html#section_api_configuration", null ]
      ] ],
      [ "Process Data API", "page_api.html#section_pd_api_functions", null ],
      [ "ISDU/Parameter API", "page_api.html#section_isdu_api_functions", null ],
      [ "Event API", "page_api.html#section_evt_api_functions", null ],
      [ "Data Storage API", "page_api.html#section_ds_api_functions", null ]
    ] ],
    [ "Implementation", "_implementation.html", [
      [ "Hardware Port", "page_hwport.html", null ],
      [ "Device Communication", "page_startcom.html", null ],
      [ "Data Storage", "page_datastorage.html", null ]
    ] ],
    [ "API Reference", "modules.html", "modules" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Related Information", "usergroup1.html", [
      [ "IO-Link Specification v1.1.2", "^http://www.io-link.com/share/Downloads/Spec-Interface/IOL-Interface-Spec_10002_V112_Jul13.pdf", null ],
      [ "IO-Link Test Specification v1.1.2", "^http://www.io-link.com/share/Downloads/Testspec/IOL-Test-Spec_10032_V112_Jul14.pdf", null ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"_implementation.html",
"group__group__iol__types.html#ggaabedc17180f6c9346ae9c8d39cc79088afaa40bb4f03b50e7ba0b4ddf9167f5af",
"releasenotes.html#version_release10303",
"struct_i_o_l_m___s_m_i___s_p_d_in.html#a42885f8cd7887a1dd850d95560e9f388",
"struct_p_l___slot_param__t.html#a44ef0c3a23233b352ee9ea4ebcbe96c1"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
